/*!
  * Licensed Materials - Property of IBM
  * 5725N95, 5725P55, 5725N96
  * (C) Copyright IBM Corp. 1999, 2014.
  * US Government Users Restricted Rights- Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

 /* $Id: viewer.js,v 1.1.2.4 2016/11/30 19:47:03 dvardhan Exp $ */
 
TreeController = 
{
	init : function()
	{
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.handleNavigation,this,true);

		var root = vc.root;
		
		var t = this.tree = new YAHOO.widget.TreeView("tree_container");
		
		var leaf = vc.isLeaf(root);
		if (leaf)
		{
			this.addTreeNode(root,t.getRoot(),!leaf);
		}
		else
		{
			this.addTreeNodeChildren(root,t.getRoot(),true);
		}

		t.subscribe("clickEvent",TreeController.nodeClicked);
		//t.subscribe("expandComplete",TreeController.nodeExpanded);
		t.render();
		
		if (vc.current != null)
		{
			this.handleNavigation("navigation",[vc.current]);
		}
	},
	addTreeNode : function(obj, parentNode, addChildren)
	{
		if (obj.type != 1)
		{
			var n = new YAHOO.widget.TextNode({ label: obj.label, obj: obj, expanded:false, hasIcon:true }, parentNode);
			if (addChildren)
			{
				this.addTreeNodeChildren(obj,n,true);
			}
		}
	},
	addTreeNodeChildren : function(obj, parentNode, addChildren)
	{
		if (obj.children)
		{
			var c;
			for (var i=0; i<obj.children.length; i++)
			{
				c = obj.children[i];
				if (!ViewerController.isRemoved(c))
				{
					this.addTreeNode(obj.children[i], parentNode, true);
				}
			}
		}
	},
	handleNavigation : function(type, args)
	{
		var yd = YAHOO.util.Dom;
		var obj = args[0];
		
		if (this.current != null)
		{
			var last = this.tree.getNodeByProperty("obj",this.current);
			if (last != null)
			{
				yd.removeClass(last.getEl(),"activeNode");
			}
		}
		
		this.current = obj;

		var node = this.tree.getNodeByProperty("obj",obj);
		if (node != null)
		{
			var p = node;
			while ((p = p.parent) != null)
			{
				p.expand();
			}
			
			yd.addClass(node.getEl(),"activeNode");
		}
		else
		{
			this.tree.collapseAll();
		}
	},
	nodeClicked : function(e)
	{
		ViewerController.navigateTo(e.node.data.obj);
		return false;
	}
}

ProgressController = 
{
	init : function()
	{
		$(".progressbar").progression({ 
				aBackground:"#2264C3", 
				Current:0, 
				Maximum: 100,
				Background: '#FFFFFF',
				TextColor: '#000000',
				aTextColor: '#FFFFFF',
				BorderColor: '#4a5661',
				Animate: true,
				AnimateTimeOut: 3000,
				Easing: 'linear' });
	
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.update,this,true);
		vc.events.load.subscribe(this.update,this,true);
		vc.events.score.subscribe(this.update,this,true);

		if (vc.current != null)
		{
			this.update();
		}
	},
	update : function()
	{
		var p = ViewerController.getPosition();
		document.getElementById("page_count").innerHTML = (p.position+1)+" of "+p.total;
		
		var c = Math.ceil((p.total > 0) ? ((ViewerController.getAccessedCount()/p.total)*100) : 0);
		
		$(".progressbar").progression({ Current:c });
	}
}

ButtonController = 
{
	disableNext : false,
	init : function()
	{
		this.prevGroupButton = new YAHOO.widget.Button("prevBtn", { name:"prevBtn", onclick:{ fn:function() { ViewerController.previous() } } }); 
		this.nextGroupButton = new YAHOO.widget.Button("nextBtn", { name:"nextBtn", onclick:{ fn:function() { ViewerController.next() }  } }); 
		
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.update,this,true);
		vc.events.score.subscribe(this.update,this,true);
		vc.events.load.subscribe(this.update,this,true);

		if (vc.current != null)
		{
			this.update();
		}
		
		if(this.disableNext){
			var cb = function()
			{
				this.disableNext = false;
				this.update();
				this.disableNext = true;
			}
			YAHOO.util.Event.addListener("groupFrame","load",cb,this,true);
		}
	},
	update : function()
	{
		jQuery("#prevBtn img")[0].src = (ViewerController.previous(true)) ? ButtonController.prevBtnImg[0] : ButtonController.prevBtnImg[1];
		jQuery("#nextBtn img")[0].src = (ViewerController.next(true)) ? ButtonController.nextBtnImg[0] : ButtonController.nextBtnImg[1];
		jQuery("#prevBtn img")[0].alt = (ViewerController.previous(true)) ? "Back" : "Back Disabled";
		jQuery("#nextBtn img")[0].alt = (ViewerController.next(true)) ? "Next" : "Next Disabled";
		this.prevGroupButton.set("disabled",!ViewerController.previous(true));
		this.nextGroupButton.set("disabled",!ViewerController.next(true));
		
		if(this.disableNext){
			this.nextGroupButton.set("disabled",true);
			jQuery("#nextBtn img")[0].src = ButtonController.nextBtnImg[1];
		}
	}
}

BreadCrumbController = 
{
	init : function()
	{
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.update,this,true);

		if (vc.current != null)
		{
			this.update("navigation",[vc.current]);
		}
	},
	update : function(type,args)
	{
		var yd = YAHOO.util.Dom;
		var obj = args[0];
		
		var cfg = ["root_label","lo_label","group_label"];
		for (var i=0; i<cfg.length; i++)
		{
			yd.get(cfg[i]).innerHTML = "";
		}
		
		var pMap = {};
		var p = obj;
		while ((p = p.parent) != null)
		{
			pMap[p.type] = p;
		}
		
		if (!obj.parent)
		{
			yd.get("root_label").innerHTML = obj.label;
		}
		else if (obj.parent.type == 5)
		{
			yd.get("root_label").innerHTML = obj.parent.label;
			yd.get("lo_label").innerHTML = obj.label;
		}
		else if (obj.parent.type == 4)
		{
			if (pMap[5])
			{
				yd.get("root_label").innerHTML = pMap[5].label;
				yd.get("lo_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else
			{
				yd.get("root_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
		}
		else if (obj.parent.type == 3)
		{
			if (pMap[5])
			{
				yd.get("root_label").innerHTML = pMap[5].label;
				yd.get("lo_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else if (pMap[4])
			{
				yd.get("root_label").innerHTML = pMap[4].label;
				yd.get("lo_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else
			{
				yd.get("root_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
		}
		else if (obj.parent.type == 2)
		{
			if (pMap[5])
			{
				yd.get("root_label").innerHTML = pMap[5].label;
				yd.get("lo_label").innerHTML = pMap[3].label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else if (pMap[4])
			{
				yd.get("root_label").innerHTML = pMap[4].label;
				yd.get("lo_label").innerHTML = pMap[3].label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else if (pMap[3])
			{
				yd.get("root_label").innerHTML = pMap[3].label;
				yd.get("group_label").innerHTML = obj.label;
			}
			else
			{
				yd.get("root_label").innerHTML = obj.parent.label;
				yd.get("group_label").innerHTML = obj.label;
			}
		}
	}
}

FeedBackWindow = 
{
	styleSheet : null,
	init : function()
	{
		OSDeliveryEngine.events.feedback.subscribe(FeedBackWindow.show,FeedBackWindow,true);
	},
	show: function(type,args)
	{
		if (type == 'feedback')
		{
			var s = "<html><head><title>" + window["FeedbackTitle"] + "</title>";
			
			if (FeedBackWindow.styleSheet != null)
			{
				s += "<link rel=\"stylesheet\" href=\""+FeedBackWindow.styleSheet+"\" type=\"text/css\"/>";
			}
			
			s += "<script language=\"javascript\">";
			for (var i=0; i<OSDeliveryEngine.LAUNCH_FUNCTIONS.length; i++)
			{
				s += OSDeliveryEngine.LAUNCH_FUNCTIONS[i]+" = window.opener."+OSDeliveryEngine.LAUNCH_FUNCTIONS[i]+";";
			}
			s += "function init() { document.getElementById('fdbka').focus(); }\n";
			s += "</script>";
			
			s += "</head><body onload=\"init()\">";
			s += "<h2><a id=\"fdbka\" name=\"feedback_title\">"+window["FeedbackTitle"]+"</a></h2>"
			s += BaseAssessmentContent.buildRemediationHTML(args[0]);
			s += "<a id=\"close\" href=\"#\" onclick=\"window.close()\" title=\"close\">close</a>";
			s += "</body></html>";
			
			var validate = args[0];
			var link = "";
			if(validate.auto){
				var link = validated.auto.link;
				w=window.open(link,"feedbackWindow","scrollbars=yes,status=no,width=400,height=200,resizable=yes");
				if (w.opener == null) w.opener = window;
			}else{
			
				w=window.open("","feedbackWindow","scrollbars=yes,status=no,width=400,height=200,resizable=yes");
				if (w.opener == null) w.opener = window;
				w.document.open();
				w.document.write(s);
				w.document.close();
			}
			
			
			w.focus();
		
			return false;
		}
	}
};

HintWindow = 
{
	styleSheet : null,
	init: function()
	{
		OSDeliveryEngine.events.hint.subscribe(HintWindow.show,HintWindow,true);
	},
	show: function(type,args)
	{
		if (type == 'hint')
		{
			var s = "<html><head><title>" + window["sHint"] + "</title>";
			
			if (HintWindow.styleSheet != null)
			{
				s += "<link rel=\"stylesheet\" href=\""+HintWindow.styleSheet+"\" type=\"text/css\"/>";
			}

			s += "</head><body>";
			s += "<div class=\"hint\">" + args[0] + "</div>";
			s += "<a id=\"close\" href=\"#\" onclick=\"window.close()\" title=\"close\">close</a>";
			s += "</body></html>";
		
			w=window.open("","feedbackWindow","scrollbars=yes,status=no,width=400,height=200,resizable=yes");
			if (w.opener == null) w.opener = window;
			w.document.open();
			w.document.write(s);
			w.document.close();
			w.focus();
		
			return false;
		}
	}
};

TopicNavController = 
{
	init : function()
	{
		jQuery("#tlsmt").click(TopicNavController.changeTopic);
		
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.update,this,true);
		vc.events.score.subscribe(this.update,this,true);
		vc.events.load.subscribe(this.update,this,true);

		if (vc.current != null)
		{
			this.update("navigation",[vc.current]);
		}
	},
	changeTopic : function()
	{
		ViewerController.navigateTo(jQuery("#tls").val());
	},
	update : function(type,args)
	{
		var obj = args[0];
		do
		{
			var elm = jQuery("#tls option[value="+obj.uniqueId+"]");
			if (elm.length == 1)
			{
				if (!elm.attr("selected"))
				{
					elm.attr("selected","selected");
				}
				break;
			}
		}
		while ((obj = obj.parent) != null);
		
		jQuery("#tls option").each(this.validate);
	},
	validate : function(index,value)
	{
		var elm = jQuery(value);
		var obj = OSDeliveryEngine.getObjectByUniqueId(elm.val());
		if (obj != null)
		{
			if (ViewerController.isEnabled(obj))
			{
				// jquery 3.x requires us to use prop.
				//elm.removeAttr("disabled");
				elm.prop("disabled", false); 
			}
			else
			{
				elm.attr("disabled","disabled");
			}
		}
	}
};

WindowTitleController = 
{
	init : function()
	{
		var vc = ViewerController;
		vc.events.navigate.subscribe(this.update,this,true);

		if (vc.current != null)
		{
			this.update("navigation",[vc.current]);
		}
	},
	update : function(type,args)
	{
		var obj = args[0];
		var root = null;
		var p = obj.parent;
		while (p != null)
		{
			root = p;
			p = p.parent;
		}
		document.title = root.label + " - "+obj.label;
	}
};

GroupController = 
{
	// force the focus to the content frame after the initial load
	init : function()
	{
		jQuery("#skip")[0].focus();
	}
}